asr.phonons
===========

.. automodule:: asr.phonons

   
   
   .. rubric:: Functions

   
   .. autofunction:: creates
   .. autofunction:: mingocorrection
   .. autofunction:: plot_bandstructure
   .. autofunction:: plot_phonons
   .. autofunction:: requires
   .. autofunction:: todict
   .. autofunction:: topckl
   .. autofunction:: webpanel
   
   

   
   
   

   
   
   